==> videosdk-0.0.3.tar.gz: lib/meeting_builder.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:videosdk/src/features/me/bloc/me_bloc.dart';
import 'package:videosdk/src/features/media_devices/bloc/media_devices_bloc.dart';
import 'package:videosdk/src/features/peers/bloc/peers_bloc.dart';
import 'package:videosdk/src/features/producers/bloc/producers_bloc.dart';
import 'package:videosdk/src/features/room/bloc/room_bloc.dart';
import 'package:videosdk/src/features/signaling/room_client_repository.dart';
import 'package:videosdk/meeting.dart';
import 'package:videosdk/src/room_modules.dart';
import 'package:events2/events2.dart';
import 'package:random_string/random_string.dart';

class MeetingBuilder extends StatelessWidget {
  final Function builder;
  final String displayName;
  final String meetingId;
  final String token;
  final bool micEnabled;
  final bool webcamEnabled;
  late final EventEmitter _eventEmitter;
  late final String localParticipantId;

  MeetingBuilder({
    Key? key,
    required this.builder,
    required this.displayName,
    required this.meetingId,
    required this.token,
    required this.micEnabled,
    required this.webcamEnabled,
  }) : super(key: key) {
    this._eventEmitter = new EventEmitter();
    this.localParticipantId = randomAlpha(8);
  }

  @override
  Widget build(BuildContext parentContext) {
    return BlocProvider<MediaDevicesBloc>(
      create: (context) => MediaDevicesBloc()..add(MediaDeviceLoadDevices()),
      child: MultiBlocProvider(
        providers: getRoomModules(
          displayName,
          this._eventEmitter,
          this.localParticipantId,
        ),
        child: RepositoryProvider(
          lazy: false,
          create: (context) {
            final meState = context.read<MeBloc>().state;
            String displayName = meState.displayName;
            String id = meState.id;

            return RoomClientRepository(
              peerId: id,
              displayName: displayName,
              micEnabled: micEnabled,
              webcamEnabled: webcamEnabled,
              meetingId: meetingId,
              token: token,
              eventEmitter: this._eventEmitter,
              //
              peersBloc: context.read<PeersBloc>(),
              producersBloc: context.read<ProducersBloc>(),
              meBloc: context.read<MeBloc>(),
              roomBloc: context.read<RoomBloc>(),
              mediaDevicesBloc: context.read<MediaDevicesBloc>(),
              //
              onMeetingJoined: (_roomClientRepository) {},
            )..join();
          },
          child: MeetingWidget(builder: builder),
        ),
      ),
    );
  }
}

class MeetingWidget extends StatelessWidget {
  final Function builder;

  const MeetingWidget({Key? key, required this.builder}) : super(key: key);

  @override
  Widget build(BuildContext context) => builder(Meeting(context));
}

==> videosdk-0.0.5.tar.gz: lib/meeting_builder.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:videosdk/src/features/me/bloc/me_bloc.dart';
import 'package:videosdk/src/features/media_devices/bloc/media_devices_bloc.dart';
import 'package:videosdk/src/features/peers/bloc/peers_bloc.dart';
import 'package:videosdk/src/features/producers/bloc/producers_bloc.dart';
import 'package:videosdk/src/features/room/bloc/room_bloc.dart';
import 'package:videosdk/src/features/signaling/room_client_repository.dart';
import 'package:videosdk/meeting.dart';
import 'package:videosdk/src/room_modules.dart';
import 'package:events2/events2.dart';
import 'package:random_string/random_string.dart';

// MeetingBuilder Widget, this widget will accept config properties and will join the meeting
class MeetingBuilder extends StatelessWidget {
  final Widget Function(Meeting meeting) builder;
  final String displayName;
  final String meetingId;
  final String token;
  final bool micEnabled;
  final bool webcamEnabled;
  late final EventEmitter _eventEmitter;
  late final String localParticipantId;

  MeetingBuilder({
    Key? key,
    required this.builder,
    required this.displayName,
    required this.meetingId,
    required this.token,
    required this.micEnabled,
    required this.webcamEnabled,
  }) : super(key: key) {
    this._eventEmitter = new EventEmitter();
    this.localParticipantId = randomAlpha(8);
  }

  @override
  Widget build(BuildContext parentContext) {
    return BlocProvider<MediaDevicesBloc>(
      create: (context) => MediaDevicesBloc()..add(MediaDeviceLoadDevices()),
      child: MultiBlocProvider(
        providers: getRoomModules(
          displayName,
          this._eventEmitter,
          this.localParticipantId,
        ),
        child: RepositoryProvider(
          lazy: false,
          create: (context) {
            final meState = context.read<MeBloc>().state;
            String displayName = meState.displayName;
            String id = meState.id;

            return RoomClientRepository(
              peerId: id,
              displayName: displayName,
              micEnabled: micEnabled,
              webcamEnabled: webcamEnabled,
              meetingId: meetingId,
              token: token,
              eventEmitter: this._eventEmitter,
              //
              peersBloc: context.read<PeersBloc>(),
              producersBloc: context.read<ProducersBloc>(),
              meBloc: context.read<MeBloc>(),
              roomBloc: context.read<RoomBloc>(),
              mediaDevicesBloc: context.read<MediaDevicesBloc>(),
              //
              onMeetingJoined: (_roomClientRepository) {},
            )..join();
          },
          child: MeetingWidget(builder: builder),
        ),
      ),
    );
  }
}

class MeetingWidget extends StatelessWidget {
  final Function builder;

  const MeetingWidget({Key? key, required this.builder}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    // builder function from MeetingBuilder that passes meeting and accepts the Widget
    return builder(Meeting(context));
  }
}
